Interact with the version control system.
Interact with the version control system.
Abort if uncommitted changes exist.
Abort if uncommitted changes exist.
Commit changes to current repository. Takes an optional format string for the commit message that will be provided the version.
Commit changes to current repository. Takes an optional format string for the commit message that will be provided the version.
(parse-tag-args args)Apply a version control tag. Takes an optional tag prefix. Pass --no-sign option to skip signing, or --no-annotate to create non-release tags.
Apply a version control tag. Takes an optional tag prefix. Pass --no-sign option to skip signing, or --no-annotate to create non-release tags.
(uses-vcs project vcs)(vcs project subtask & args)Interact with the version control system.
Interact with the version control system.
(which-vcs project & _)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |